#[non_exhaustive]pub enum FailurePolicy {
FailFast,
Continue,
SkipDependents,
}Expand description
Failure handling strategy for DAG execution.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FailFast
Stop execution immediately when the first node fails.
Continue
Continue executing all nodes, even when upstream dependencies fail.
SkipDependents
Skip all downstream dependents of a failed node, but keep independent branches running.